ReportLab Preppy Test Suite 011

# Preppy Test 011 - Preppy Functions

This test passes a dictionary to Preppy. The items in this dictionary have the same names as function names within Preppy.

This test does the same to Preppy's functions as the previous test did for variables.

## Expected Output

You should see a long list of function names between the two lines.

{'unescape': 'unescape', 'printstmt': 'printstmt', 'countnewlines': 'countnewlines', 'quotestring': 'quotestring', 'diag': 'diag', 'slen': 'slen', 'quotedparts': 'quotedparts', 'addpart': 'addpart', 'indent': 'indent', '__call__': '__call__', 'check_condition': 'check_condition', 'strip': 'strip', 'getDirectiveBlock': 'getDirectiveBlock', 'module_source': 'module_source', 'proctologist': 'proctologist', 'complexdirective': 'complexdirective', 'dedent': 'dedent', 'parsetest': 'parsetest', 'testgetmodule': 'testgetmodule', 'getPreppyModule': 'getPreppyModule', 'cleantext': 'cleantext', 'new_module': 'new_module'}